@@ -54,6 +54,9 @@ class RandomForestClassifier(sklearn.ensemble.RandomForestClassifier):
             "stop_when_horizontal": stop_when_horizontal
         }
         self.logger = logging.getLogger("ASRFClassifier")
+        
+    def __str__(self):
+        return "ASRFClassifier"
     
     def predict_tree_proba(self, tree_id, X):
         return self.estimators_[tree_id].predict_proba(X)
