@@ -38,6 +38,9 @@ class RandomForestRegressor(sklearn.ensemble.RandomForestRegressor):
         }
         self.logger = logging.getLogger("ASRFClassifier")
         
+    def __str__(self):
+        return "ASRFRegressor"
+        
     def predict_tree(self, tree_id, X):
         return self.estimators_[tree_id].predict(X)
         
